==> kubernetes-model-admissionregistration-4.13.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectAccessReviewSpecFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubjectAccessReviewSpecFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<A>> extends Fluent<A> {


    public A addToExtra(String key,ArrayList<String> value);
    public A addToExtra(Map<String,ArrayList<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,ArrayList<String>> map);
    public Map<String,ArrayList<String>> getExtra();
    public A withExtra(Map<String,ArrayList<String>> extra);
    public Boolean hasExtra();
    public A addToGroup(int index,String item);
    public A setToGroup(int index,String item);
    public A addToGroup(String... items);
    public A addAllToGroup(Collection<String> items);
    public A removeFromGroup(String... items);
    public A removeAllFromGroup(Collection<String> items);
    public List<String> getGroup();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingGroup(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withGroup(List<String> group);
    public A withGroup(String... group);
    public Boolean hasGroup();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNonResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes getNonResourceAttributes();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes buildNonResourceAttributes();
    public A withNonResourceAttributes(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes nonResourceAttributes);
    public Boolean hasNonResourceAttributes();
    public A withNewNonResourceAttributes(String path,String verb);
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributes();
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes item);
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editNonResourceAttributes();
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributes();
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes item);
    
/**
 * This method has been deprecated, please use method buildResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes getResourceAttributes();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes buildResourceAttributes();
    public A withResourceAttributes(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes resourceAttributes);
    public Boolean hasResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes item);
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes item);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();
    public A withNewUser(String arg1);
    public A withNewUser(StringBuilder arg1);
    public A withNewUser(StringBuffer arg1);
    public interface NonResourceAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<SubjectAccessReviewSpecFluent.NonResourceAttributesNested<N>> {

        public N and();
        public N endNonResourceAttributes();    }


    public interface ResourceAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributesFluent<SubjectAccessReviewSpecFluent.ResourceAttributesNested<N>> {

        public N and();
        public N endResourceAttributes();    }


}

==> kubernetes-model-admissionregistration-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectAccessReviewSpecFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubjectAccessReviewSpecFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectAccessReviewSpecFluent<A>> extends Fluent<A> {


    public A addToExtra(String key,ArrayList<String> value);
    public A addToExtra(Map<String,ArrayList<String>> map);
    public A removeFromExtra(String key);
    public A removeFromExtra(Map<String,ArrayList<String>> map);
    public Map<String,ArrayList<String>> getExtra();
    public A withExtra(Map<String,ArrayList<String>> extra);
    public Boolean hasExtra();
    public A addToGroup(int index,String item);
    public A setToGroup(int index,String item);
    public A addToGroup(String... items);
    public A addAllToGroup(Collection<String> items);
    public A removeFromGroup(String... items);
    public A removeAllFromGroup(Collection<String> items);
    public List<String> getGroup();
    public String getGroup(int index);
    public String getFirstGroup();
    public String getLastGroup();
    public String getMatchingGroup(Predicate<String> predicate);
    public Boolean hasMatchingGroup(Predicate<String> predicate);
    public A withGroup(List<String> group);
    public A withGroup(String... group);
    public Boolean hasGroup();
    public A addNewGroup(String arg1);
    public A addNewGroup(StringBuilder arg1);
    public A addNewGroup(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNonResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes getNonResourceAttributes();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes buildNonResourceAttributes();
    public A withNonResourceAttributes(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes nonResourceAttributes);
    public Boolean hasNonResourceAttributes();
    public A withNewNonResourceAttributes(String path,String verb);
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributes();
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> withNewNonResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes item);
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editNonResourceAttributes();
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributes();
    public SubjectAccessReviewSpecFluent.NonResourceAttributesNested<A> editOrNewNonResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributes item);
    
/**
 * This method has been deprecated, please use method buildResourceAttributes instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes getResourceAttributes();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes buildResourceAttributes();
    public A withResourceAttributes(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes resourceAttributes);
    public Boolean hasResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> withNewResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes item);
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributes();
    public SubjectAccessReviewSpecFluent.ResourceAttributesNested<A> editOrNewResourceAttributesLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributes item);
    public String getUid();
    public A withUid(String uid);
    public Boolean hasUid();
    public A withNewUid(String arg1);
    public A withNewUid(StringBuilder arg1);
    public A withNewUid(StringBuffer arg1);
    public String getUser();
    public A withUser(String user);
    public Boolean hasUser();
    public A withNewUser(String arg1);
    public A withNewUser(StringBuilder arg1);
    public A withNewUser(StringBuffer arg1);
    public interface NonResourceAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceAttributesFluent<SubjectAccessReviewSpecFluent.NonResourceAttributesNested<N>> {

        public N and();
        public N endNonResourceAttributes();    }


    public interface ResourceAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceAttributesFluent<SubjectAccessReviewSpecFluent.ResourceAttributesNested<N>> {

        public N and();
        public N endResourceAttributes();    }


}
